<?php  
// Enable error reporting for debugging  
ini_set('display_errors', 1);  
ini_set('display_startup_errors', 1);  
error_reporting(E_ALL);  

// TMDb API Key  
$tmdbApiKey = '2bca77a6dcb0c892cd1d4b677768fa88';  

// Database connection  
$host = 'localhost';  
$dbname = 'web_api_db';  
$username = 'web_api_user';  
$password = 'BHBNCL8fa5hcWs6D';  

try {  
   $conn = new PDO("mysql:host=$host;dbname=$dbname", $username, $password);  
   $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);  
} catch (PDOException $e) {  
   die("Database connection failed: " . $e->getMessage());  
}  

// Fetch series list from the database  
function fetchSeriesList($conn) {
    $stmt = $conn->prepare("SELECT id, name, TMDB_ID FROM web_series"); // Fetch the TMDB_ID column
    $stmt->execute();
    return $stmt->fetchAll(PDO::FETCH_ASSOC);
}

// Fetch episodes from TMDb API for a given series and season  
function fetchEpisodesFromTmdb($tmdbId, $seasonNumber, $apiKey) {  
   $url = "https://api.themoviedb.org/3/tv/$tmdbId/season/$seasonNumber?api_key=$apiKey&language=en-US";  
   $data = @file_get_contents($url);  

   if ($data === false) {  
      return []; // Handle API failure gracefully  
   }  

   $seasonDetails = json_decode($data, true);  

   if (isset($seasonDetails['episodes']) && !empty($seasonDetails['episodes'])) {  
      return $seasonDetails['episodes']; // Return the episodes array if found  
   }  

   return []; // If no episodes found  
}  

// Insert episodes into the database  
function insertEpisodesIntoDb($tmdbId, $seasonId, $episodes, $conn) {
    $importedEpisodes = 0;
    foreach ($episodes as $episode) {
        $episodeName = $episode['name'];
        $episodeOrder = $episode['episode_number']; // Episode number
        $episodeDescription = $episode['overview'];
        $episodeImage = "https://image.tmdb.org/t/p/w500" . $episode['still_path']; // Thumbnail image
        $episodeUrl = "https://vidsrc.icu/embed/tv/$tmdbId/$seasonId/$episodeOrder"; // Updated URL generation

        // Check if episode already exists to avoid duplicates
        $stmt = $conn->prepare("SELECT COUNT(*) FROM web_series_episoade WHERE season_id = :season_id AND episoade_order = :episoade_order");
        $stmt->execute([':season_id' => $seasonId, ':episoade_order' => $episodeOrder]);
        if ($stmt->fetchColumn() > 0) {
            continue; // Skip if episode already exists
        }

        try {
            // Insert episode data into the table
            $stmt = $conn->prepare("INSERT INTO web_series_episoade  
                (Episoade_Name, episoade_image, episoade_description, episoade_order, season_id, downloadable, type, status, source, url)  
                VALUES  
                (:episode_name, :episode_image, :episode_description, :episode_order, :season_id, :downloadable, :type, :status, :source, :url)");

            $stmt->execute([
                ':episode_name' => $episodeName,
                ':episode_image' => $episodeImage,
                ':episode_description' => $episodeDescription,
                ':episode_order' => $episodeOrder,
                ':season_id' => $seasonId, // Linking to the season
                ':downloadable' => 0, // Default value
                ':type' => 0, // Default value (0 = Not Premium)
                ':status' => 1, // Status as Released (1)
                ':source' => 'Vidsrc', // Source
                ':url' => $episodeUrl, // Corrected URL
            ]);
            $importedEpisodes++;
        } catch (PDOException $e) {
            echo "Error inserting episode data: " . $e->getMessage();
        }
    }
    return $importedEpisodes;
}

// Handle the form submission to import episodes  
if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['series_id']) && isset($_POST['season_number'])) {  
    $seriesId = $_POST['series_id'];  
    $seasonNumber = $_POST['season_number'];  

    // Fetch series details  
    $stmt = $conn->prepare("SELECT * FROM web_series WHERE id = :series_id");  
    $stmt->execute([':series_id' => $seriesId]);  
    $series = $stmt->fetch(PDO::FETCH_ASSOC);  

    if ($series) {  
        // Check if TMDB_ID exists and is valid
        if (isset($series['TMDB_ID']) && !empty($series['TMDB_ID'])) {  
            $tmdbId = $series['TMDB_ID'];  
            
            // Fetch episodes from TMDb API for the selected series and season  
            $episodes = fetchEpisodesFromTmdb($tmdbId, $seasonNumber, $tmdbApiKey);  
            
            if (!empty($episodes)) {  
                // Insert episodes into the database  
                $importedEpisodes = insertEpisodesIntoDb($tmdbId, $seasonNumber, $episodes, $conn);  
                
                if ($importedEpisodes > 0) {  
                    echo "<script>alert('Episodes for season $seasonNumber imported successfully!');</script>";  
                } else {  
                    echo "<script>alert('No new episodes found for season $seasonNumber.');</script>";  
                }  
            } else {  
                echo "<script>alert('No episodes found for season $seasonNumber.');</script>";  
            }  
        } else {  
            echo "<script>alert('TMDB_ID not found or invalid for the selected series.');</script>";  
        }  
    } else {  
        echo "<script>alert('Series not found.');</script>";  
    }  
}
?>  

<!DOCTYPE html>  
<html lang="en">  
<head>  
   <meta charset="UTF-8">  
   <meta name="viewport" content="width=device-width, initial-scale=1.0">  
   <title>Episode Importer</title>  
   <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css">  
   <style>  
      .progress-bar {  
        width: 0%;  
        transition: width 0.5s;  
      }  
   </style>  
</head>  
<body>  
   <div class="container mt-5">  
      <h1>Episode Importer</h1>  
      <form method="POST" action="">  
        <div class="form-group">  
           <label for="series_id">Select Series:</label>  
           <select name="series_id" id="series_id" class="form-control" required>  
              <option value="">Select a Series</option>  
              <?php  
              $seriesList = fetchSeriesList($conn);  
              foreach ($seriesList as $series) {  
                echo "<option value='{$series['id']}'>{$series['name']}</option>";  
              }  
              ?>  
           </select>  
        </div>  

        <div class="form-group">  
           <label for="season_number">Enter Season Number:</label>  
           <input type="number" name="season_number" id="season_number" class="form-control" required>  
        </div>  

        <button type="submit" class="btn btn-primary">Import Episodes</button>  
      </form>  
      <div class="progress mt-3" style="height: 20px;">  
        <div class="progress-bar bg-success" id="progress-bar" role="progressbar" aria-valuenow="0" aria-valuemin="0" aria-valuemax="100">0%</div>  
      </div>  
   </div>  

   <script src="https://code.jquery.com/jquery-3.2.1.min.js"></script>  
   <script>  
      $(document).ready(function() {  
        $('form').submit(function() {  
           var seriesId = $('#series_id').val();  
           var seasonNumber = $('#season_number').val();  
           $.ajax({  
              type: 'POST',  
              url: '',  
              data: {series_id: seriesId, season_number: seasonNumber},  
              xhr: function() {  
                var xhr = new window.XMLHttpRequest();  
                xhr.upload.addEventListener("progress", function(evt) {  
                   if (evt.lengthComputable) {  
                      var percentComplete = evt.loaded / evt.total;  
                      percentComplete = parseInt(percentComplete * 100);  
                      $('#progress-bar').css('width', percentComplete + '%');  
                      $('#progress-bar').text(percentComplete + '%');  
                   }  
                }, false);  
                return xhr;  
              },  
              success: function(response) {  
                $('#progress-bar').css('width', '100%');  
                $('#progress-bar').text('100%');  
              }  
           });  
           return false;  
        });  
      });  
   </script>  
</body>  
</html>
