<?php  
// Enable error reporting for debugging  
ini_set('display_errors', 1);  
ini_set('display_startup_errors', 1);  
error_reporting(E_ALL);  
  
// TMDb API Key  
$tmdbApiKey = '2bca77a6dcb0c892cd1d4b677768fa88';  
  
// Database connection  
$host = 'localhost';  
$dbname = 'web_api_db';  
$username = 'web_api_user';  
$password = 'BHBNCL8fa5hcWs6D';  
  
try {  
   $conn = new PDO("mysql:host=$host;dbname=$dbname", $username, $password);  
   $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);  
} catch (PDOException $e) {  
   die("Database connection failed: " . $e->getMessage());  
}  
  
// Fetch all series names and their TMDb IDs for dropdown  
function getSeriesList($conn) {  
   $stmt = $conn->prepare("SELECT id, name, tmdb_id FROM web_series");  
   $stmt->execute();  
   return $stmt->fetchAll(PDO::FETCH_ASSOC);  
}  
  
// Fetch seasons for a series based on TMDb ID  
function fetchSeasonsFromTmdb($tmdbId, $apiKey) {  
   // Correct API endpoint for fetching TV show details (including seasons)  
   $url = "https://api.themoviedb.org/3/tv/$tmdbId?api_key=$apiKey&language=en-US";  
   $data = @file_get_contents($url);  
  
   if ($data === false) {  
      return []; // Handle API failure gracefully  
   }  
  
   // Log the raw API response for debugging  
   error_log("TMDb API Response: " . $data); // Log the raw response to debug  
  
   $showDetails = json_decode($data, true);  
  
   // Check if 'seasons' exists in the API response  
   if (isset($showDetails['seasons']) && !empty($showDetails['seasons'])) {  
      return $showDetails['seasons']; // Return the seasons array if found  
   }  
  
   return []; // If no seasons, return an empty array  
}  
  
// Check if the series' seasons are already imported  
function areSeasonsImported($seriesId, $conn) {  
   $stmt = $conn->prepare("SELECT COUNT(*) FROM web_series_seasons WHERE web_series_id = :series_id");  
   $stmt->execute([':series_id' => $seriesId]);  
   return $stmt->fetchColumn() > 0; // Return true if seasons are already imported  
}  
  
// Insert seasons into the `web_series_seasons` table  
function insertSeasonsIntoDb($webSeriesId, $seasons, $conn) {  
   foreach ($seasons as $season) {  
      $seasonName = $season['name'];  
      $seasonOrder = $season['season_number']; // Order of the season  
  
      try {  
        // Insert season data into 'web_series_seasons' table  
        $stmt = $conn->prepare("INSERT INTO web_series_seasons (Session_Name, season_order, web_series_id, status)  
                        VALUES (:season_name, :season_order, :web_series_id, :status)");  
  
        $stmt->execute([  
           ':season_name' => $seasonName,  
           ':season_order' => $seasonOrder,  
           ':web_series_id' => $webSeriesId, // Linking to the web series  
           ':status' => 1, // Assuming default status as 1 (adjust as needed)  
        ]);  
      } catch (PDOException $e) {  
        echo "Error inserting season data for TMDb ID $webSeriesId: " . $e->getMessage() . "<br>";  
      }  
   }  
}  
  
// Processing form submission to import seasons for selected series  
$message = "";  
$success = false;  
if ($_SERVER['REQUEST_METHOD'] == 'POST' && !empty($_POST['series_id'])) {  
   $seriesId = $_POST['series_id'];  
  
   // Fetch series details using the series ID  
   $stmt = $conn->prepare("SELECT tmdb_id, name FROM web_series WHERE id = :series_id");  
   $stmt->execute([':series_id' => $seriesId]);  
   $series = $stmt->fetch(PDO::FETCH_ASSOC);  
  
   if ($series) {  
      $tmdbId = $series['tmdb_id'];  
      $seriesName = $series['name'];  
  
      // Check if the seasons for this series have already been imported  
      if (areSeasonsImported($seriesId, $conn)) {  
        $message = "Seasons for '$seriesName' are already imported.";  
      } else {  
        // Fetch the seasons for the series based on the TMDb ID  
        $seasons = fetchSeasonsFromTmdb($tmdbId, $tmdbApiKey);  
  
        if (!empty($seasons)) {  
           // Insert the fetched seasons into the `web_series_seasons` table  
           insertSeasonsIntoDb($seriesId, $seasons, $conn);  
           $message = "Seasons for '$seriesName' have been imported successfully.";  
  
           // Redirect to automate_episode.php after success  
           header("Location: automate_episode.php");  
           exit(); // Ensure no further code execution after the redirect  
        } else {  
           $message = "No seasons found for '$seriesName'.";  
        }  
      }  
   } else {  
      $message = "Series not found.";  
   }  
}  
?>  
  
<!DOCTYPE html>  
<html lang="en">  
<head>  
   <meta charset="UTF-8">  
   <meta name="viewport" content="width=device-width, initial-scale=1.0">  
   <title>Import TV Series Seasons</title>  
   <link rel="stylesheet" href="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/css/bootstrap.min.css">  
   <style>  
      body {  
        background-color: #f5f5f5;  
      }  
      .container {  
        max-width: 500px;  
        margin: 50px auto;  
        padding: 20px;  
        background-color: #fff;  
        border: 1px solid #ddd;  
        border-radius: 10px;  
        box-shadow: 0 0 10px rgba(0, 0, 0, 0.1);  
      }  
      .form-group {  
        margin-bottom: 20px;  
      }  
      .btn-primary {  
        background-color: #007bff;  
        border-color: #007bff;  
      }  
      .btn-primary:hover {  
        background-color: #0069d9;  
        border-color: #0069d9;  
      }  
      .alert {  
        margin-top: 20px;  
      }  
   </style>  
</head>  
<body>  
   <div class="container">  
      <h2 class="text-center">Import TV Series Seasons</h2>  
      <form method="post" action="">  
        <div class="form-group">  
           <label for="series_id">Select Series:</label>  
           <select name="series_id" id="series_id" class="form-control">  
              <option value="">-- Select a Series --</option>  
              <?php  
              // Fetch and display the list of series  
              $seriesList = getSeriesList($conn);  
              foreach ($seriesList as $series) {  
                echo "<option value='" . $series['id'] . "'>" . htmlspecialchars($series['name']) . "</option>";  
              }  
              ?>  
           </select>  
        </div>  
  
        <button type="submit" class="btn btn-primary">Import Seasons</button>  
      </form>  
      <?php if (!empty($message)) { ?>  
        <div class="alert alert-<?php echo $success ? 'success' : 'danger'; ?>">  
           <?php echo $message; ?>  
        </div>  
      <?php } ?>  
   </div>  
  
   <script src="https://code.jquery.com/jquery-3.2.1.min.js"></script>  
   <script src="https://maxcdn.bootstrapcdn.com/bootstrap/4.0.0/js/bootstrap.min.js"></script>  
</body>  
</html>
