<?php
// Enable error reporting for debugging
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

// TMDb API Key
$tmdbApiKey = '2bca77a6dcb0c892cd1d4b677768fa88';

// Database connection
$host = 'localhost';
$dbname = 'web_api_db';
$username = 'web_api_user';
$password = 'BHBNCL8fa5hcWs6D';

try {
    $conn = new PDO("mysql:host=$host;dbname=$dbname", $username, $password);
    $conn->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

// Function to fetch YouTube trailer
function fetchYouTubeTrailer($tmdbId, $apiKey) {
    $url = "https://api.themoviedb.org/3/tv/$tmdbId/videos?api_key=$apiKey";
    $data = @file_get_contents($url);

    if ($data === false) {
        return ''; // Handle API failure gracefully
    }

    $videos = json_decode($data, true);

    if (!empty($videos['results'])) {
        foreach ($videos['results'] as $video) {
            if ($video['site'] === 'YouTube' && $video['type'] === 'Trailer') {
                return 'https://www.youtube.com/watch?v=' . $video['key'];
            }
        }
    }
    return ''; // No valid trailer found
}

// Function to fetch IMDb rating, logo, and languages
function fetchImdbRatingLogoAndLanguages($tmdbId, $apiKey) {
    $url = "https://api.themoviedb.org/3/tv/$tmdbId?api_key=$apiKey";
    $data = @file_get_contents($url);

    if ($data === false) {
        return [null, null, '']; // Handle API failure gracefully
    }

    $showData = json_decode($data, true);

    if (!empty($showData)) {
        // IMDb rating
        $imdbRating = $showData['vote_average']; // TMDb uses 'vote_average' as IMDb rating

        // Fetch logo separately from the images endpoint
        $logo = '';
        $logoUrl = "https://api.themoviedb.org/3/tv/$tmdbId/images?api_key=$apiKey";
        $imageData = @file_get_contents($logoUrl);

        if ($imageData !== false) {
            $images = json_decode($imageData, true);
            if (!empty($images['logos'])) {
                foreach ($images['logos'] as $img) {
                    if ($img['iso_639_1'] === 'en') { // Filter for English logo
                        $logo = 'https://image.tmdb.org/t/p/w500' . $img['file_path'];
                        break;
                    }
                }
            }
        }

        // Languages
        $languages = implode(', ', array_map(function ($lang) {
            return $lang['english_name'];
        }, $showData['spoken_languages']));

        return [$imdbRating, $logo, $languages];
    }

    return [null, null, '']; // No data found
}

// Processing form submission
$message = "";
$success = false;
if ($_SERVER['REQUEST_METHOD'] == 'POST' && !empty($_POST['tmdb_ids'])) {
    $tmdbIds = explode(',', $_POST['tmdb_ids']);

    foreach ($tmdbIds as $tmdbId) {
        $tmdbId = trim($tmdbId);

        // Fetch TV show data from TMDb
        $tmdbUrl = "https://api.themoviedb.org/3/tv/$tmdbId?api_key=$tmdbApiKey&language=en-US";
        $tmdbData = @file_get_contents($tmdbUrl);
        if ($tmdbData === false) {
            $message .= "Error fetching data for TMDb ID $tmdbId.<br>";
            continue;
        }
        $showData = json_decode($tmdbData, true);

        if (!empty($showData)) {
            $name = $showData['name'];
            $description = $showData['overview'];
            $genres = implode(', ', array_map(function ($genre) {
                return $genre['name'];
            }, $showData['genres']));
            $release_date = $showData['first_air_date']; // For TV shows, use 'first_air_date'
            $poster = 'https://image.tmdb.org/t/p/w500' . $showData['poster_path'];
            $banner = 'https://image.tmdb.org/t/p/w500' . $showData['backdrop_path'];
            $youtube_trailer = fetchYouTubeTrailer($tmdbId, $tmdbApiKey);
            list($imdbRating, $logo, $languages) = fetchImdbRatingLogoAndLanguages($tmdbId, $tmdbApiKey);

            try {
                // Insert TV show data into the 'web_series' table
                $stmt = $conn->prepare("INSERT INTO web_series (TMDB_ID, name, description, genres, release_date, poster, banner, logo, imdb_rating, languages, youtube_trailer, downloadable, type, status, content_type) 
                                        VALUES (:tmdb_id, :name, :description, :genres, :release_date, :poster, :banner, :logo, :imdb_rating, :languages, :youtube_trailer, :downloadable, :type, :status, :content_type)");

                $stmt->execute([
                    ':tmdb_id' => $tmdbId,
                    ':name' => $name,
                    ':description' => $description,
                    ':genres' => $genres,
                    ':release_date' => $release_date,
                    ':poster' => $poster,
                    ':banner' => $banner,
                    ':logo' => $logo,
                    ':imdb_rating' => $imdbRating,
                    ':languages' => $languages,
                    ':youtube_trailer' => $youtube_trailer,
                    ':downloadable' => 0, // Default value (adjust as needed)
                    ':type' => 0, // Default value (adjust as needed)
                    ':status' => 1, // Default value (adjust as needed)
                    ':content_type' => 2, // Default value (adjust as needed)
                ]);

                $success = true;
            } catch (PDOException $e) {
                $message .= "Database error for TMDb ID $tmdbId: " . $e->getMessage() . "<br>";
            }
        } else {
            $message .= "No data found for TMDb ID $tmdbId.<br>";
        }
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Import Web Series</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
</head>
<body>
    <div class="container mt-5">
        <div class="card">
            <div class="card-header text-center bg-primary text-white">
                <h1>Import Web Series</h1>
            </div>
            <div class="card-body">
                <form method="post" action="">
                    <div class="mb-3">
                        <label for="tmdb_ids" class="form-label">Enter TMDb TV Show IDs (comma separated):</label>
                        <input type="text" id="tmdb_ids" name="tmdb_ids" class="form-control" required>
                    </div>
                    <button type="submit" class="btn btn-primary w-100">Import</button>
                </form>
            </div>
        </div>
    </div>
   <?php if ($success): ?>
    <script>
        // Redirect to automate_season_tv.php after showing the success message
        Swal.fire({
            icon: 'success',
            title: 'Web Series Imported',
            text: 'Web series have been successfully imported!',
            confirmButtonText: 'OK'
        }).then(() => {
            window.location.href = 'automate_season_tv.php'; // Redirect after the success message is acknowledged
        });
    </script>
<?php endif; ?>

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>
</html>
