<?php
// Set CORS headers
header('Access-Control-Allow-Origin: https://api.threeminutesfix.in'); // Change to '*' to allow all domains
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

// Handle preflight request for OPTIONS method
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Get parameters
$api_key = isset($_GET['api_key']) ? $_GET['api_key'] : '';
$id = isset($_GET['id']) ? $_GET['id'] : '';
$language = isset($_GET['language']) ? $_GET['language'] : 'en';

// Validate parameters
if (empty($api_key) || empty($id)) {
    echo json_encode(["error" => "Missing required parameters."]);
    exit;
}

// Fetch movie images including logos
$images_url = "https://api.themoviedb.org/3/movie/$id/images?api_key=$api_key&language=$language";
$images_response = @file_get_contents($images_url);

if ($images_response === FALSE) {
    echo json_encode(["error" => "Error occurred while fetching movie images from TMDB."]);
    exit;
}

// Decode the images response
$images_data = json_decode($images_response, true);

// Check for logos in images data
$logo_url = null;
if (isset($images_data['logos']) && count($images_data['logos']) > 0) {
    // Get the first logo's file path
    $logo_path = $images_data['logos'][0]['file_path'];
    $logo_url = "https://image.tmdb.org/t/p/original$logo_path";
}

// Prepare the response with the logo only
if ($logo_url) {
    echo json_encode(['logo' => $logo_url]);
} else {
    echo json_encode(['error' => 'Logo not found.']);
}
?>
