<?php
// Set CORS headers
header('Access-Control-Allow-Origin: https://api.threeminutesfix.in'); // Change to '*' to allow all domains
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

// Handle preflight request for OPTIONS method
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Get parameters
$api_key = isset($_GET['api_key']) ? $_GET['api_key'] : '';
$id = isset($_GET['id']) ? $_GET['id'] : '';
$language = isset($_GET['language']) ? $_GET['language'] : 'en';

// Validate parameters
if (empty($api_key) || empty($id)) {
    echo json_encode(["error" => "Missing required parameters."]);
    exit;
}

// Fetch movie details from TMDB
$movie_url = "https://api.themoviedb.org/3/movie/$id?api_key=$api_key&language=$language";
$movie_response = @file_get_contents($movie_url);

if ($movie_response === FALSE) {
    echo json_encode(["error" => "Error occurred while fetching movie data from TMDB."]);
    exit;
}

// Decode the movie response
$movie_data = json_decode($movie_response, true);

// Check for errors in movie data
if (isset($movie_data['success']) && !$movie_data['success']) {
    echo json_encode(["error" => "Movie not found."]);
    exit;
}

// Return the movie data as a JSON response
echo json_encode($movie_data);
?>
