<?php
// Set CORS headers
header('Access-Control-Allow-Origin: https://watchflix.threeminutesfix.in'); // Change to '*' to allow all domains if needed
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

// Handle preflight request for OPTIONS method
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Get parameters
$api_key = isset($_GET['api_key']) ? $_GET['api_key'] : '';
$id = isset($_GET['id']) ? $_GET['id'] : '';
$language = isset($_GET['language']) ? $_GET['language'] : 'en';

// Validate parameters
if (empty($api_key) || empty($id)) {
    echo json_encode(["error" => "Missing required parameters."]);
    exit;
}

// Fetch TV series data from TMDB API
$tv_series_url = "https://api.themoviedb.org/3/tv/$id?api_key=$api_key&language=$language";
$tv_series_response = @file_get_contents($tv_series_url);

if ($tv_series_response === FALSE) {
    echo json_encode(["error" => "Error occurred while fetching TV series data from TMDB."]);
    exit;
}

// Decode the TV series response
$tv_series_data = json_decode($tv_series_response, true);

// Check for errors in TV series data
if (isset($tv_series_data['success']) && !$tv_series_data['success']) {
    echo json_encode(["error" => "TV series not found."]);
    exit;
}

// Return the TV series data as a JSON response
echo json_encode($tv_series_data);
?>
