<?php
// Set CORS headers
header('Access-Control-Allow-Origin: https://api.threeminutesfix.in');
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');
header('Content-Type: application/json');

// Handle preflight request for OPTIONS method
if ($_SERVER['REQUEST_METHOD'] === 'OPTIONS') {
    http_response_code(200);
    exit;
}

// Get parameters
$api_key = isset($_GET['api_key']) ? $_GET['api_key'] : '';
$id = isset($_GET['id']) ? $_GET['id'] : '';
$language = isset($_GET['language']) ? $_GET['language'] : 'en';

// Validate parameters
if (empty($api_key) || empty($id)) {
    echo json_encode(["error" => "Missing required parameters."]);
    exit;
}

// Fetch TV series details from TMDB
$series_url = "https://api.themoviedb.org/3/tv/$id?api_key=$api_key&language=$language";
$series_response = @file_get_contents($series_url);

if ($series_response === FALSE) {
    echo json_encode(["error" => "Error occurred while fetching series data from TMDB."]);
    exit;
}

// Decode the series response
$series_data = json_decode($series_response, true);

// Check for errors in series data
if (isset($series_data['success']) && !$series_data['success']) {
    echo json_encode(["error" => "Series not found."]);
    exit;
}

// Return the series data as a JSON response
echo json_encode($series_data);
?>
