<?php
header('Content-Type: application/json');
header('Access-Control-Allow-Origin: https://api.threeminutesfix.in'); // Change to '*' to allow all domains
header('Access-Control-Allow-Methods: GET, POST, OPTIONS');
header('Access-Control-Allow-Headers: Content-Type, Authorization');

function fetchAllTrailers($tmdbApiKey, $tvId) {
    // TMDB API URL to fetch TV series videos
    $url = "https://api.themoviedb.org/3/tv/" . $tvId . "/videos?api_key=" . $tmdbApiKey . "&language=en-US";
    
    // Get the response from TMDB
    $response = file_get_contents($url);
    $responseData = json_decode($response, true);

    // Prepare an array to hold trailers
    $trailers = [];
    
    // Check if videos exist
    if ($responseData && isset($responseData['results']) && count($responseData['results']) > 0) {
        $trailerCount = 1;

        foreach ($responseData['results'] as $video) {
            // Check if the video is a trailer and is from YouTube
            if ($video['type'] == "Trailer" && $video['site'] == "YouTube") {
                $trailers["trailer_" . $trailerCount] = "https://www.youtube.com/watch?v=" . $video['key'];
                $trailerCount++;
            }
        }
    }

    // Return trailers or error if none found
    return count($trailers) > 0 ? $trailers : ["error" => "No trailers found."];
}

// Main entry point
if (isset($_GET['api_key']) && isset($_GET['id'])) {
    $tmdbApiKey = $_GET['api_key'];
    $tvId = $_GET['id']; // Change from imdbId to tvId

    $trailers = fetchAllTrailers($tmdbApiKey, $tvId);
    
    // Return the response in JSON format
    echo json_encode($trailers);
} else {
    // Return an error if the parameters are missing
    echo json_encode(["error" => "API key and TV ID are required."]);
}
?>
