<?php  
  
// The allowed origin, strictly for cloud.threeminutesfix.in  
$allowed_origin = 'https://cloud.threeminutesfix.in';  
  
// Get the Origin header from the incoming request  
$origin = isset($_SERVER['HTTP_ORIGIN']) ? $_SERVER['HTTP_ORIGIN'] : '';  
  
// Check if the Origin header matches the allowed origin  
if ($origin !== $allowed_origin) {  
   header('HTTP/1.1 403 Forbidden');  
   echo json_encode(array('error' => 'Forbidden: Invalid Origin'));  
   exit;  
}  
  
// Set the URL of the GZIP file and movie name from the request parameters   
$url = $_GET['url'];   
$movie_name = $_GET['movie_name'];  // The movie name passed from Android   
  
// Generate a unique filename using a hash based on the movie name and subtitle content  
$vtt_filename = md5($movie_name . $url) . '.vtt';  // Unique hash filename  
  
// Define the path where the VTT file will be saved  
$vtt_path = 'subtitles/' . $vtt_filename;  // Ensure the 'subtitles' directory exists and is writable  
  
// Check if the subtitle file already exists  
if (file_exists($vtt_path)) {  
   // If the file exists, return the existing subtitle URL  
   header('Content-Type: application/json');  
   echo json_encode(array(  
      'exists' => true,  
      'url' => 'http://' . $_SERVER['HTTP_HOST'] . '/subtitles/' . $vtt_filename,  
      'message' => 'Subtitle already exists.'  
   ));  
   exit;  
}  
  
// Download the GZIP file   
$gz_data = file_get_contents($url);   
  
// Decompress the GZIP file   
$srt_data = gzdecode($gz_data);   
  
// Check if decompression was successful  
if ($srt_data === false) {  
   echo json_encode(array('error' => 'Failed to decode GZIP file.'));  
   exit;  
}  
  
// Sanitize the subtitle data by converting any undefined or invalid characters to a valid format  
$srt_data = mb_convert_encoding($srt_data, 'UTF-8', 'UTF-8');  
  
// Remove BOM if present (UTF-8 BOM is 0xEF 0xBB 0xBF)  
$srt_data = preg_replace('/^\xEF\xBB\xBF/', '', $srt_data);  
  
// Convert SRT to VTT  
$vtt_data = convertSRTtoVTT($srt_data);  
  
// Open the VTT file for writing  
$vtt_file = fopen($vtt_path, 'wb');  
  
// Write the VTT data in chunks  
$chunk_size = 1024 * 1024; // 1MB chunks  
$offset = 0;  
while ($offset < strlen($vtt_data)) {  
   $chunk = substr($vtt_data, $offset, $chunk_size);  
   fwrite($vtt_file, $chunk);  
   $offset += $chunk_size;  
}  
  
// Close the VTT file  
fclose($vtt_file);  
  
// Clean up old subtitle files (older than 30 days)  
cleanupOldSubtitles(30);  
  
// Return the file details as JSON  
header('Content-Type: application/json');  
$response = array(  
   'exists' => false,  
   'filename' => $vtt_filename,  
   'url' => 'http://' . $_SERVER['HTTP_HOST'] . '/subtitles/' . $vtt_filename,  // URL to access the subtitle  
   'message' => 'New subtitle file created.'  
);  
echo json_encode($response);  
  
// Function to convert SRT to VTT  
function convertSRTtoVTT($srt_data) {  
   // Add the "WEBVTT" header to the beginning of the file  
   $vtt_data = "WEBVTT\n\n";  
  
   // Replace commas with periods for the timestamps and remove unnecessary newlines  
   $srt_data = preg_replace('/(\d{2}):(\d{2}):(\d{2}),(\d{3}) --> (\d{2}):(\d{2}):(\d{2}),(\d{3})/',  
                    '$1:$2:$3.$4 --> $5:$6:$7.$8', $srt_data);  
  
   // Append the converted SRT data to the VTT format  
   $vtt_data .= $srt_data;  
  
   return $vtt_data;  
}  
  
// Function to clean up old subtitle files  
function cleanupOldSubtitles($days) {  
   $directory = 'subtitles/';  
   $files = glob($directory . '*.vtt');  
    
   $current_time = time();  
   $expiry_time = $days * 86400; // Convert days to seconds  
    
   foreach ($files as $file) {  
      if (filemtime($file) < $current_time - $expiry_time) {  
        // Delete files older than the specified number of days  
        unlink($file);  
      }  
   }  
}  
?>
